@@ -4,7 +4,7 @@
 <!--BEGIN STABILITY BANNER-->---
 
 
-![Stability: Stable](https://img.shields.io/badge/stability-Stable-success.svg?style=for-the-badge)
+![cdk-constructs: Stable](https://img.shields.io/badge/cdk--constructs-stable-success.svg?style=for-the-badge)
 
 ---
 <!--END STABILITY BANNER-->
@@ -26,7 +26,7 @@ import jsii
 import jsii.compat
 import publication
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/cdk-assets-schema", "1.32.1", __name__, "cdk-assets-schema@1.32.1.jsii.tgz")
+from ._jsii import *
 
 
 class AssetManifestSchema(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/cdk-assets-schema.AssetManifestSchema"):
@@ -52,7 +52,7 @@ class AssetManifestSchema(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/cdk-asset
 
     @jsii.member(jsii_name="input")
     @builtins.classmethod
-    def input(cls, *, version: str, docker_images: typing.Optional[typing.Mapping[str,"DockerImageAsset"]]=None, files: typing.Optional[typing.Mapping[str,"FileAsset"]]=None) -> None:
+    def input(cls, *, version: str, docker_images: typing.Optional[typing.Mapping[str, "DockerImageAsset"]]=None, files: typing.Optional[typing.Mapping[str, "FileAsset"]]=None) -> None:
         """Take a ManifestFile as input.
 
         The presence of this method makes sure the struct is only ever weakened
@@ -78,7 +78,7 @@ class AssetManifestSchema(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/cdk-asset
 
 @jsii.data_type(jsii_type="@aws-cdk/cdk-assets-schema.AwsDestination", jsii_struct_bases=[], name_mapping={'assume_role_arn': 'assumeRoleArn', 'assume_role_external_id': 'assumeRoleExternalId', 'region': 'region'})
 class AwsDestination():
-    def __init__(self, *, assume_role_arn: typing.Optional[str]=None, assume_role_external_id: typing.Optional[str]=None, region: typing.Optional[str]=None):
+    def __init__(self, *, assume_role_arn: typing.Optional[str]=None, assume_role_external_id: typing.Optional[str]=None, region: typing.Optional[str]=None) -> None:
         """Destination for assets that need to be uploaded to AWS.
 
         :param assume_role_arn: The role that needs to be assumed while publishing this asset. Default: - No role will be assumed
@@ -130,7 +130,7 @@ class AwsDestination():
 
 @jsii.data_type(jsii_type="@aws-cdk/cdk-assets-schema.DockerImageAsset", jsii_struct_bases=[], name_mapping={'destinations': 'destinations', 'source': 'source'})
 class DockerImageAsset():
-    def __init__(self, *, destinations: typing.Mapping[str,"DockerImageDestination"], source: "DockerImageSource"):
+    def __init__(self, *, destinations: typing.Mapping[str, "DockerImageDestination"], source: "DockerImageSource") -> None:
         """A file asset.
 
         :param destinations: Destinations for this file asset.
@@ -143,7 +143,7 @@ class DockerImageAsset():
         }
 
     @builtins.property
-    def destinations(self) -> typing.Mapping[str,"DockerImageDestination"]:
+    def destinations(self) -> typing.Mapping[str, "DockerImageDestination"]:
         """Destinations for this file asset."""
         return self._values.get('destinations')
 
@@ -164,7 +164,7 @@ class DockerImageAsset():
 
 @jsii.data_type(jsii_type="@aws-cdk/cdk-assets-schema.DockerImageDestination", jsii_struct_bases=[AwsDestination], name_mapping={'assume_role_arn': 'assumeRoleArn', 'assume_role_external_id': 'assumeRoleExternalId', 'region': 'region', 'image_tag': 'imageTag', 'repository_name': 'repositoryName'})
 class DockerImageDestination(AwsDestination):
-    def __init__(self, *, assume_role_arn: typing.Optional[str]=None, assume_role_external_id: typing.Optional[str]=None, region: typing.Optional[str]=None, image_tag: str, repository_name: str):
+    def __init__(self, *, assume_role_arn: typing.Optional[str]=None, assume_role_external_id: typing.Optional[str]=None, region: typing.Optional[str]=None, image_tag: str, repository_name: str) -> None:
         """Where to publish docker images.
 
         :param assume_role_arn: The role that needs to be assumed while publishing this asset. Default: - No role will be assumed
@@ -230,7 +230,7 @@ class DockerImageDestination(AwsDestination):
 
 @jsii.data_type(jsii_type="@aws-cdk/cdk-assets-schema.DockerImageSource", jsii_struct_bases=[], name_mapping={'directory': 'directory', 'docker_build_args': 'dockerBuildArgs', 'docker_build_target': 'dockerBuildTarget', 'docker_file': 'dockerFile'})
 class DockerImageSource():
-    def __init__(self, *, directory: str, docker_build_args: typing.Optional[typing.Mapping[str,str]]=None, docker_build_target: typing.Optional[str]=None, docker_file: typing.Optional[str]=None):
+    def __init__(self, *, directory: str, docker_build_args: typing.Optional[typing.Mapping[str, str]]=None, docker_build_target: typing.Optional[str]=None, docker_file: typing.Optional[str]=None) -> None:
         """Properties for how to produce a Docker image from a source.
 
         :param directory: The directory containing the Docker image build instructions. This path is relative to the asset manifest location.
@@ -254,7 +254,7 @@ class DockerImageSource():
         return self._values.get('directory')
 
     @builtins.property
-    def docker_build_args(self) -> typing.Optional[typing.Mapping[str,str]]:
+    def docker_build_args(self) -> typing.Optional[typing.Mapping[str, str]]:
         """Additional build arguments.
 
         default
@@ -292,7 +292,7 @@ class DockerImageSource():
 
 @jsii.data_type(jsii_type="@aws-cdk/cdk-assets-schema.FileAsset", jsii_struct_bases=[], name_mapping={'destinations': 'destinations', 'source': 'source'})
 class FileAsset():
-    def __init__(self, *, destinations: typing.Mapping[str,"FileDestination"], source: "FileSource"):
+    def __init__(self, *, destinations: typing.Mapping[str, "FileDestination"], source: "FileSource") -> None:
         """A file asset.
 
         :param destinations: Destinations for this file asset.
@@ -305,7 +305,7 @@ class FileAsset():
         }
 
     @builtins.property
-    def destinations(self) -> typing.Mapping[str,"FileDestination"]:
+    def destinations(self) -> typing.Mapping[str, "FileDestination"]:
         """Destinations for this file asset."""
         return self._values.get('destinations')
 
@@ -334,7 +334,7 @@ class FileAssetPackaging(enum.Enum):
 
 @jsii.data_type(jsii_type="@aws-cdk/cdk-assets-schema.FileDestination", jsii_struct_bases=[AwsDestination], name_mapping={'assume_role_arn': 'assumeRoleArn', 'assume_role_external_id': 'assumeRoleExternalId', 'region': 'region', 'bucket_name': 'bucketName', 'object_key': 'objectKey'})
 class FileDestination(AwsDestination):
-    def __init__(self, *, assume_role_arn: typing.Optional[str]=None, assume_role_external_id: typing.Optional[str]=None, region: typing.Optional[str]=None, bucket_name: str, object_key: str):
+    def __init__(self, *, assume_role_arn: typing.Optional[str]=None, assume_role_external_id: typing.Optional[str]=None, region: typing.Optional[str]=None, bucket_name: str, object_key: str) -> None:
         """Where in S3 a file asset needs to be published.
 
         :param assume_role_arn: The role that needs to be assumed while publishing this asset. Default: - No role will be assumed
@@ -400,7 +400,7 @@ class FileDestination(AwsDestination):
 
 @jsii.data_type(jsii_type="@aws-cdk/cdk-assets-schema.FileSource", jsii_struct_bases=[], name_mapping={'path': 'path', 'packaging': 'packaging'})
 class FileSource():
-    def __init__(self, *, path: str, packaging: typing.Optional["FileAssetPackaging"]=None):
+    def __init__(self, *, path: str, packaging: typing.Optional["FileAssetPackaging"]=None) -> None:
         """Describe the source of a file asset.
 
         :param path: The filesystem object to upload. This path is relative to the asset manifest location.
@@ -440,7 +440,7 @@ class FileSource():
 
 @jsii.data_type(jsii_type="@aws-cdk/cdk-assets-schema.ManifestFile", jsii_struct_bases=[], name_mapping={'version': 'version', 'docker_images': 'dockerImages', 'files': 'files'})
 class ManifestFile():
-    def __init__(self, *, version: str, docker_images: typing.Optional[typing.Mapping[str,"DockerImageAsset"]]=None, files: typing.Optional[typing.Mapping[str,"FileAsset"]]=None):
+    def __init__(self, *, version: str, docker_images: typing.Optional[typing.Mapping[str, "DockerImageAsset"]]=None, files: typing.Optional[typing.Mapping[str, "FileAsset"]]=None) -> None:
         """Definitions for the asset manifest.
 
         :param version: Version of the manifest.
@@ -459,7 +459,7 @@ class ManifestFile():
         return self._values.get('version')
 
     @builtins.property
-    def docker_images(self) -> typing.Optional[typing.Mapping[str,"DockerImageAsset"]]:
+    def docker_images(self) -> typing.Optional[typing.Mapping[str, "DockerImageAsset"]]:
         """The Docker image assets in this manifest.
 
         default
@@ -468,7 +468,7 @@ class ManifestFile():
         return self._values.get('docker_images')
 
     @builtins.property
-    def files(self) -> typing.Optional[typing.Mapping[str,"FileAsset"]]:
+    def files(self) -> typing.Optional[typing.Mapping[str, "FileAsset"]]:
         """The file assets in this manifest.
 
         default
@@ -510,6 +510,18 @@ class Placeholders(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/cdk-assets-schem
         return jsii.sget(cls, "CURRENT_REGION")
 
 
-__all__ = ["AssetManifestSchema", "AwsDestination", "DockerImageAsset", "DockerImageDestination", "DockerImageSource", "FileAsset", "FileAssetPackaging", "FileDestination", "FileSource", "ManifestFile", "Placeholders", "__jsii_assembly__"]
+__all__ = [
+    "AssetManifestSchema",
+    "AwsDestination",
+    "DockerImageAsset",
+    "DockerImageDestination",
+    "DockerImageSource",
+    "FileAsset",
+    "FileAssetPackaging",
+    "FileDestination",
+    "FileSource",
+    "ManifestFile",
+    "Placeholders",
+]
 
 publication.publish()
